import { SerializableValue } from '@previewjs/serializable-values';
import { TypeAnalyzer, ValueType, CollectedTypes } from '@previewjs/type-analyzer';
import { Reader } from '@previewjs/vfs';
import { Logger } from 'pino';

type Analyzer = {
    typeAnalyzer: Omit<TypeAnalyzer, "dispose">;
    crawlFiles: (filePaths: string[]) => Promise<{
        components: Component[];
        stories: Story[];
    }>;
    dispose: () => void;
};
type AnalyzerFactory = (options: {
    rootDir: string;
    reader?: Reader;
    logger?: Logger;
}) => Analyzer;
interface BasePreviewable {
    id: string;
    sourcePosition: FileSourcePosition;
}
interface Component extends BasePreviewable {
    exported: boolean;
    analyze: () => Promise<ComponentAnalysis>;
}
interface ComponentAnalysis {
    props: ValueType;
    types: CollectedTypes;
}
interface Story extends BasePreviewable {
    analyze: () => Promise<StoryAnalysis>;
    associatedComponent: BasicComponent | null;
}
interface StoryAnalysis {
    args: StoryArgs | null;
}
type StoryArgs = {
    sourcePosition: FileSourcePosition;
    value: SerializableValue;
};
type FileSourcePosition = {
    start: number;
    end: number;
};
type BasicComponent = Pick<Component, "id" | "analyze">;

type AnalyzerFactoryOptions = Parameters<AnalyzerFactory>[0];
declare function factoryWithDefaultOptions(factory: (options: Required<AnalyzerFactoryOptions>) => Analyzer): AnalyzerFactory;

declare function generatePreviewableId(options: {
    filePath: string;
    name: string;
}): string;
declare function decodePreviewableId(id: string): {
    filePath: string;
    name: string;
};

export { type Analyzer, type AnalyzerFactory, type BasePreviewable, type BasicComponent, type Component, type ComponentAnalysis, type FileSourcePosition, type Story, type StoryAnalysis, type StoryArgs, decodePreviewableId, factoryWithDefaultOptions, generatePreviewableId };
